@@ -201,7 +201,7 @@ package Uplug::Config;
 require 5.004;
 
 use strict;
-use vars qw($VERSION @ISA @EXPORT);
+use vars qw(@ISA @EXPORT);
 use vars qw(%NamedIO);
 
 use FindBin qw/$Bin/;
@@ -209,8 +209,6 @@ use FindBin qw/$Bin/;
 use Exporter qw/import/;
 use Data::Dumper;
 
-$VERSION = 0.02;
-
 our @EXPORT   = qw/FindConfig ReadConfig WriteConfig 
                    PrintConfigInfo
                    ListAvailableModules
